import os
import json
import random
import string

def generate_random_string(length):
    characters = string.ascii_letters + string.digits + ' '
    return ''.join(random.choice(characters) for _ in range(length))

def generate_random_filename():
    characters = string.ascii_letters + string.digits + '-_'
    length = random.randint(1, 32)
    return ''.join(random.choice(characters) for _ in range(length))

def generate_test_data():
    movie_id = generate_random_filename()
    name = generate_random_string(random.randint(8, 32))
    description = generate_random_string(random.randint(8, 256))
    version = 1
    replay = random.choice([True, False])
    
    files = []
    pages = []
    
    # Create movie_id folder
    os.makedirs(movie_id, exist_ok=True)
    
    # Create textures folder
    textures_folder = os.path.join(movie_id, 'textures')
    os.makedirs(textures_folder, exist_ok=True)
    
    # Generate files and copy template.png
    template_file = 'template.png'
    for _ in range(random.randint(1, 20)):
        file_id = generate_random_filename()
        filename = f'yl_cinema_{movie_id}_{file_id}.png'
        files.append(filename)
        file_path = os.path.join(textures_folder, filename)
        os.system(f'cp {template_file} {file_path}')
    
    # Generate pages
    for order in range(1, random.randint(1, 20) + 1):
        texture = random.choice(files)
        if random.random() < 0.05:
            texture += random.choice(['^[invert:rgb', '^[transformR180'])
        caption = generate_random_string(random.randint(8, 32))
        captionposx = random.randint(1, 8)
        captionposy = random.randint(1, 8)
        duration = round(random.uniform(0.3, 8), 1)
        
        page = {
            'order': order,
            'texture': texture,
            'caption': caption,
            'captionposx': captionposx,
            'captionposy': captionposy,
            'duration': duration
        }
        pages.append(page)
    
    # Create JSON data
    data = {
        'movie_id': movie_id,
        'name': name,
        'description': description,
        'version': version,
        'replay': replay,
        'title_texture': random.choice(files),
        'files': files,
        'pages': pages
    }
    
    # Write JSON to file
    json_data = json.dumps(data, indent=4)
    filename = os.path.join(movie_id, f'{movie_id}.json')
    with open(filename, 'w') as file:
        file.write(json_data)

# Generate 10 JSON files
for _ in range(10):
    generate_test_data()
